@@ -12,6 +12,12 @@ import zc.recipe.egg
 
 logger = logging.getLogger(__name__)
 
+MONGO_BINARIES = (
+    'mongo', 'mongodb', 'mongodump', 'mongoexport',
+    'mongofiles', 'mongoimport', 'mongorestore', 'mongos',
+    'mongosniff', 'mongostat'
+)
+
 
 class Recipe(zc.recipe.egg.Eggs):
     """Buildout recipe for installing mongoDB."""
@@ -81,9 +87,10 @@ class Recipe(zc.recipe.egg.Eggs):
             logger.info("mongoDB already installed.")
 
         bindir = self.buildout['buildout']['bin-directory']
-        mongod = os.path.join(bindir, 'mongod')
-        if not os.path.isfile(mongod):
-            shutil.copy(os.path.join(dst, 'bin', 'mongod'), mongod)
+        for fn in MONGO_BINARIES:
+            fullname = os.path.join('dst', 'bin', fn)
+            if os.path.exists(fullname):
+                shutil.copy(fullname, bindir)
 
         for path in remove_after_install:
             shutil.rmtree(path)
@@ -99,9 +106,10 @@ class Recipe(zc.recipe.egg.Eggs):
         """Updates the part."""
 
         bindir = self.buildout['buildout']['bin-directory']
-        mongod = os.path.join(bindir, 'mongod')
-        if os.path.isfile(mongod):
-            os.remove(mongod)
+        for fn in MONGO_BINARIES:
+            fullname = os.path.join(bindir, fn)
+            if os.path.isfile(fullname):
+                os.remove(fullname)
         dst = os.path.join(self.buildout['buildout']['parts-directory'],
                            self.name)
         if os.path.isdir(dst):
